@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: cf.c 296 2018-07-27 01:23:25Z leres $ (XSE)
+ * @(#) $Id: cf.c 299 2019-04-07 20:59:42Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018
  *	Craig Leres
@@ -66,7 +66,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 	f = fopen(fn, "r");
 	if (f == NULL) {
 		if (mustexist) {
-			fprintf(stderr, "%s: readcf: fopen %s/%s: %s\n",
+			fprintf(stderr, "%s: readcf: fopen %s%s: %s\n",
 			    prog, prefix, fn, strerror(errno));
 			++errs;
 		}
