@@ -1,4 +1,4 @@
-/* @(#) $Id: gif.h 266 2015-07-04 21:39:04Z leres $ (XSE) */
+/* @(#) $Id: gif.h 287 2017-01-21 19:15:36Z leres $ (XSE) */
 #ifndef gif_h
 #define gif_h
 
@@ -11,5 +11,5 @@ struct gifheader {
 	u_char h1, h2;
 };
 
-int parsegif(const char *, int *, int *);
+int parsegif(const char *, int *, int *, struct timespec *);
 #endif
